@@ -17,21 +17,25 @@ Geo::Address::Parser - Lightweight country-aware address parser from flat text
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # Supported countries and their corresponding rule modules
 my %COUNTRY_MODULE = (
 	US => 'Geo::Address::Parser::Rules::US',
 	USA => 'Geo::Address::Parser::Rules::US',
 	UK => 'Geo::Address::Parser::Rules::UK',
+	GB => 'Geo::Address::Parser::Rules::UK',
 	CA => 'Geo::Address::Parser::Rules::CA',
 	'Canada' => 'Geo::Address::Parser::Rules::CA',
 	AU => 'Geo::Address::Parser::Rules::AU',
 	'AUSTRALIA' => 'Geo::Address::Parser::Rules::AU',
+	IE => 'Geo::Address::Parser::Rules::IRL',     # Ireland ISO code
+	IRL => 'Geo::Address::Parser::Rules::IRL',    # 3-letter code
+	'IRELAND' => 'Geo::Address::Parser::Rules::IRL', # Full name
 	NZ => 'Geo::Address::Parser::Rules::NZ',
 	'NEW ZEALAND' => 'Geo::Address::Parser::Rules::NZ',
 );
@@ -54,7 +58,11 @@ This module extracts address components from flat text input. It supports
 lightweight parsing for the US, UK, Canada, Australia, and New Zealand, using
 country-specific regular expressions.
 
-The object can be configured using the methods described in L<Object::Configure>.
+The class can be configured at runtime using environments and configuration files,
+for example,
+setting C<$ENV{'GEO__ADDRESS__PARSER__carp_on_warn'}> causes warnings to use L<Carp>.
+For more information about runtime configuration,
+see L<Object::Configure>.
 
 =head2 new(country => $code)
 
@@ -157,7 +165,12 @@ sub parse
 
 	my $text = $params->{'text'};
 
-	croak 'No input text provided' unless defined $text;
+	if(!defined($text)) {
+		if($self->{'logger'}) {
+			$self->{'logger'}->error(ref($self) . ':parse(): No input text provided');
+		}
+		croak('No input text provided');
+	}
 
 	my $parser = $self->{module};
 
@@ -178,6 +191,24 @@ sub parse
 	return Return::Set::set_return($result, { 'type' => 'hashref', 'min' => 2 });
 }
 
+=head1 SUPPORT
+
+This module is provided as-is without any warranty.
+
+Please report any bugs or feature requests to C<bug-geo-address-parser at rt.cpan.org>,
+or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Geo-Address-Parser>.
+I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<Object::Configure>
+
+=back
+
 =head1 LICENCE AND COPYRIGHT
 
 Copyright 2025 Nigel Horne.
